@@ -207,11 +207,8 @@ class PyHtmlGuiInstance:
                 string_to_render = module.TEMPLATE_STR
 
         if self._parent.auto_reload is True:
-            self._parent.add_file_to_monitor(file_to_monitor, item.__class__.__name__)
+            self._parent._add_file_to_monitor(file_to_monitor, item.__class__.__name__)
 
-        #  replace onclick="pyview.my_function(arg1,arg2)"
-        #  with    onclick="pyhtmlgui.call({{_create_py_function_reference(pyview.my_function)}}, arg1, arg2)
-        # this a a convinience function is user does not have to type the annoying stuff and functions look cleaner
         string_to_render = self._prepare_template(string_to_render)
 
         try:
